=======
History
=======


0.3.7 (2021-01-09)
------------------

* Added top-k accuracy computation, TensorBoardMetricLogger
* ProgressTracker preserves len of iterable


0.3.5 (2021-01-08)
------------------

* ProgressTracker tracks iterations inside each epoch
* Cleaner version of checkpoint saver
* Added tests
* Drop support of python 3.5
* Added to_device and apply_recursively helpers


0.3.0 (2020-11-02)
------------------

Added tools for training: metric processors, checkpoint creation, progress tracking, dictionary conversion


0.2.0 (2020-11-02)
------------------

* added visualization functions


0.1.1 (2020-07-05)
------------------

* Setup tests, docs


0.1.0 (2020-07-02)
------------------

* First release on PyPI.
